import warnings
warnings.simplefilter('ignore', Warning)


from gencmd.tests.new import *
from gencmd.tests.controller import *
from gencmd.tests.model import *
from gencmd.tests.scaffold import *



